@@ -44,10 +44,10 @@ class SimpleRocks(object):
             gc.collect()
 
     def __setitem__(self, key, value):
-        self.db.put(key, value)
+        self.put(key, value)
 
     def __getitem__(self, key_):
-        val = self.db.get(key_)
+        val = self.get(key_)
         if val is None:
             raise KeyError(f'{key_} not in {self}')
         return val
